**Usage**

|PythonVersion|_ |License|_ |PoweredBy|_

**Development**

|Pep8|_ |Doc|_

**Release**

|PyPi|_


.. |PythonVersion| image:: https://img.shields.io/badge/python-3.8%20%7C%203.12-blue
.. _PythonVersion: https://github.com/neurospincloud-ci/pycaravel

.. |Pep8| image:: https://github.com/neurospincloud-ci/pycaravel/actions/workflows/pep8.yml/badge.svg
.. _Pep8: https://github.com/neurospincloud-ci/pycaravel/actions

.. |PyPi| image:: https://badge.fury.io/py/pycaravel.svg
.. _PyPi: https://badge.fury.io/py/pycaravel

.. |Doc| image:: https://github.com/neurospincloud-ci/pycaravel/actions/workflows/documentation.yml/badge.svg
.. _Doc: http://neurospincloud-ci.github.io/pycaravel

.. |License| image:: https://img.shields.io/badge/License-CeCILLB-blue.svg
.. _License: http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html

.. |PoweredBy| image:: https://img.shields.io/badge/Powered%20by-CEA%2FNeuroSpin-blue.svg
.. _PoweredBy: https://joliot.cea.fr/drf/joliot/Pages/Entites_de_recherche/NeuroSpin.aspx


pycaravel
=========

This module is designed to simplify continuous integration (CI) of data from
multiple projects.


Important links
===============

- Official source code repo: https://github.com/neurospincloud-ci/pycaravel
- HTML documentation: http://neurospincloud-ci.github.io/pycaravel


Dependencies
============

The required dependencies to use the software are:

* pandas
* grabbit
* nibabel
* numpy
* imageio
* PyPDF2
* vcfpy
* pandas-plink
* pyEDFlib
* requests
* python-docx
* fire
* pymzml


Install
=======

Check the official documentation dedicated page.
